#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: asymptote
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION	: 2010-06-13
# BUILD-ONLY DEPS	: tetex, texinfo
# NOTES				: -

### Checking for unbound variables and exit on errors
set -u -e

### Repo
URL=http://zenwalk.pinguix.com/user-accounts/skywatcher

### Pkg variables
NAME="asymptote"
VERSION="1.97"
ARCH="i686"
CPU="i686"
BUILD="64.1"
EXT="txz"
HOMEPAGE="http://asymptote.sourceforge.net"
SRCLNK="http://downloads.sourceforge.net/asymptote/$NAME-$VERSION.src.tgz"
DESCRIPTION="A vector graphics language"
DOCS="TODO README INSTALL BUGS ChangeLog LICENSE"
ADDSRC=""
INCSRC=""
ADDDEP="Imaging"
XCLDEP=""

### Script variables
CWD=`pwd`
PKG=$NAME-$VERSION-$ARCH-$BUILD
URL=$URL/$NAME/$VERSION
PKGDIR=$CWD/$NAME-install
SRCDIR=$CWD/$NAME-$VERSION
SRCPKG=`echo $SRCLNK | cut -d\  -f1 | rev | cut -d/ -f1 | rev`

### Flags and jobs
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
NJOBS="-j4"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Making default package dirs
install -dv $SRCDIR $PKGDIR/{install,usr/src/$NAME-$VERSION}

### Getting sources
for src in $SRCLNK; do \
	source=`echo $src | rev | cut -d/ -f1 | rev` 
	if [ -f $source ]; then
		echo "Source file $source is already present, no need to download it";
	else
		echo "Downloading $source..."
		wget -c -nv $SRCLNK
	fi
done

### Extracting main sources
tar xfv $SRCPKG -C $SRCDIR --strip-components=1

### Building ===========================================================
cd $SRCDIR

### Ensure latex is found
PATH=$PATH:/usr/share/texmf/bin/

# Compiling and installing
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man \
			--with-docdir=/usr/doc/$NAME-$VERSION --infodir=/usr/info \
			--enable-gc=system || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

# Providing a default config file to match zenwalk software
# A personal config.asy can be placed in the $HOME/.asy dir
cat > $PKGDIR/usr/share/$NAME/config.asy << EOF
import settings;
psviewer="evince";
pdfviewer="evince";
gs="gs";
EOF

# Using relative linking for the executable
rm -rf $PKGDIR/usr/bin/xasy
cd $PKGDIR/usr/bin
ln -s ../share/asymptote/GUI/xasy.py xasy

# Fixing tex files path
mv $PKGDIR/usr/share/texmf-local $PKGDIR/usr/share/texmf

# Icon
convert $SRCDIR/asy.ico $SRCDIR/asy.png
install -Dv $SRCDIR/asy.png $PKGDIR/usr/share/icons/hicolor/48x48/apps/asy.png
mogrify -resize 48x48 $PKGDIR/usr/share/icons/hicolor/48x48/apps/asy.png

### Desktop entry
install -dv $PKGDIR/usr/share/applications/
cat > $PKGDIR/usr/share/applications/$NAME.desktop << EOF
[Desktop Entry]
Name=Asymptote
Comment=Vector graphics program
Exec=Terminal -e asy -T asymptote
Icon=asy
Type=Application
Categories=Graphics;VectorGraphics
Terminal=false
StartupNotify=true
Encoding=UTF-8
EOF

cat > $PKGDIR/usr/share/applications/xasy.desktop << EOF
[Desktop Entry]
Name=Asymptote-Xasy
Comment=Asymptote GUI
Exec=xasy
Icon=asy
Type=Application
Categories=Graphics;VectorGraphics
Terminal=false
StartupNotify=true
Encoding=UTF-8
EOF

# Docs, man, info
cd $SRCDIR
install -dv $PKGDIR/usr/doc/$NAME-$VERSION
install -v $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
mv -v $PKGDIR/usr/info/asymptote/asymptote.info $PKGDIR/usr/info/asymptote.info

# Unnedeed stuff
rm -frv $PKGDIR/usr/info/asymptote/

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: Asymptote is a powerful descriptive vector graphics language that 
$NAME: provides a natural coordinate-based framework for technical drawing.
$NAME: Labels and equations are typeset with LaTeX, for high-quality 
$NAME: PostScript output.
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Doinstall

# infodir 
cat > $PKGDIR/install/doinst.sh << EOF
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=usr/info usr/info/asy-faq.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=usr/info usr/info/asymptote.info.gz 2>/dev/null
fi
EOF

# ======================================================================

### Managing and zipping man and info files
if [ -d $PKGDIR/usr/man ]; then
	find $PKGDIR/usr/man -type f -exec gzip -9 -v {} \;
fi
if [ -d $PKGDIR/usr/info ]; then
	find $PKGDIR/usr/info -type f -exec gzip -9 -v {} \;
fi

### Adding build-file and included stuff to the package
for file in $0 $INCSRC
	do cp -av $CWD/$file $PKGDIR/usr/src/$NAME-$VERSION
done
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Stripping binaries
cd $PKGDIR
set +e
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
set -e

### Making the package
makepkg -l y -c n $CWD/$PKG.$EXT
cd $CWD

### md5
md5sum $PKG.$EXT > $PKG.md5

### dep
ADD=$ADDDEP EXCLUDE=$XCLDEP requiredbuilder -z $PKG.$EXT > $PKG.dep

### slackdesc
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
echo $SRCLNK > $PKG.src
for link in $0 $ADDSRC 
	do echo $URL/$link >> $PKG.src
done

### Cleaning
DEL_BLDDIR=${DEL_BLDDIR:-1}
if [ "$DEL_BLDDIR" -eq "1" ]; then
	rm -rf $SRCDIR
	rm -rf $PKGDIR
fi

### Done. Ciao!
